| %ni% | R Documentation |
Evaluates whether the left hand side argument is not in the right hand side argument.
lhs %ni% rhs
lhs |
left hand side. |
rhs |
right hand side. |
The %ni% function negates the %in% operator.
The function returns a vector of the same length as lhs.
Mathijs Deen
c(1,2,3) %ni% c(1,2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.